.. SPDX-License-Identifier: Apache-2.0

API reference
=============

This page presents the complete API documentation.

.. autosummary::
    :toctree: generated

    axon_synthesis
    axon_synthesis.atlas
    axon_synthesis.base_path_builder
    axon_synthesis.constants
    axon_synthesis.typing
    axon_synthesis.utils
    axon_synthesis.validation
    axon_synthesis.validation.mimic
    axon_synthesis.validation.statistics
    axon_synthesis.white_matter_recipe
    axon_synthesis.cli
    axon_synthesis.cli.common
    axon_synthesis.cli.input_creation
    axon_synthesis.cli.synthesis
    axon_synthesis.cli.utils
    axon_synthesis.cli.validation
    axon_synthesis.inputs
    axon_synthesis.inputs.clustering
    axon_synthesis.inputs.clustering.extract_terminals
    axon_synthesis.inputs.clustering.from_barcodes
    axon_synthesis.inputs.clustering.from_brain_regions
    axon_synthesis.inputs.clustering.from_sphere_parents
    axon_synthesis.inputs.clustering.from_spheres
    axon_synthesis.inputs.clustering.plot
    axon_synthesis.inputs.clustering.utils
    axon_synthesis.inputs.create
    axon_synthesis.inputs.pop_neuron_numbers
    axon_synthesis.inputs.trunk_properties
    axon_synthesis.synthesis
    axon_synthesis.synthesis.add_tufts
    axon_synthesis.synthesis.main_trunk
    axon_synthesis.synthesis.main_trunk.create_graph
    axon_synthesis.synthesis.main_trunk.create_graph.plot
    axon_synthesis.synthesis.main_trunk.create_graph.utils
    axon_synthesis.synthesis.main_trunk.post_process
    axon_synthesis.synthesis.main_trunk.steiner_morphology
    axon_synthesis.synthesis.main_trunk.steiner_tree
    axon_synthesis.synthesis.outputs
    axon_synthesis.synthesis.plot
    axon_synthesis.synthesis.source_points
    axon_synthesis.synthesis.target_points
    axon_synthesis.synthesis.tuft_properties
